@@ -1,11 +1,18 @@
 """Contains all database models."""
+from typing import TYPE_CHECKING
 
-from django.db import models
+from django.db import models, connection
 from django.db.models import QuerySet
 
 import core.musiq.song_queue
 import core.musiq.song_utils as song_utils
 
+if connection.vendor == "postgresql":
+    from django.contrib.postgres.indexes import GinIndex, OpClass
+
+if TYPE_CHECKING:
+    from core.musiq.song_utils import Metadata
+
 
 # Create your models here.
 class Tag(models.Model):
@@ -19,7 +26,7 @@ class Tag(models.Model):
 
 
 class Counter(models.Model):
-    """Stores the visitors counter. Only has one elment."""
+    """Stores the visitors counter. Only has one element."""
 
     value = models.IntegerField()
 
@@ -34,7 +41,9 @@ class ArchivedSong(models.Model):
     url = models.CharField(max_length=2000, unique=True)
     artist = models.CharField(max_length=1000)
     title = models.CharField(max_length=1000)
+    duration = models.FloatField()
     counter = models.IntegerField()
+    cached = models.BooleanField()
 
     def __str__(self) -> str:
         return self.title + " (" + self.url + "): " + str(self.counter)
@@ -43,6 +52,32 @@ class ArchivedSong(models.Model):
         """Formats the song using the utility method."""
         return song_utils.displayname(self.artist, self.title)
 
+    def get_metadata(self) -> "Metadata":
+        return {
+            "artist": self.artist,
+            "title": self.title,
+            "duration": self.duration,
+            "external_url": self.url,
+            "cached": self.cached,
+        }
+
+    class Meta:
+
+        indexes = (
+            [
+                GinIndex(
+                    OpClass("artist", "gin_trgm_ops"),
+                    name="core_archivedsong_artist_trgm",
+                ),
+                GinIndex(
+                    OpClass("title", "gin_trgm_ops"),
+                    name="core_archivedsong_title_trgm",
+                ),
+            ]
+            if connection.vendor == "postgresql"
+            else []
+        )
+
 
 class ArchivedPlaylist(models.Model):
     """Stores an archived playlist.
@@ -86,6 +121,19 @@ class ArchivedQuery(models.Model):
     def __str__(self) -> str:
         return self.query
 
+    class Meta:
+        if connection.vendor == "postgresql":
+            indexes = (
+                [
+                    GinIndex(
+                        OpClass("query", "gin_trgm_ops"),
+                        name="core_archivedquery_query_trgm",
+                    )
+                ]
+                if connection.vendor == "postgresql"
+                else []
+            )
+
 
 class ArchivedPlaylistQuery(models.Model):
     """Stores the queries from the musiq page and the ArchivedPlaylist it lead to."""
@@ -111,7 +159,7 @@ class QueuedSong(models.Model):
     stream_url = models.CharField(max_length=2000, blank=True, null=True)
     artist = models.CharField(max_length=1000)
     title = models.CharField(max_length=1000)
-    duration = models.IntegerField()
+    duration = models.FloatField()
     objects = core.musiq.song_queue.SongQueue()
 
     def __str__(self) -> str:
@@ -133,7 +181,7 @@ class CurrentSong(models.Model):
     votes = models.IntegerField()
     artist = models.CharField(max_length=1000)
     title = models.CharField(max_length=1000)
-    duration = models.IntegerField()
+    duration = models.FloatField()
     internal_url = models.CharField(max_length=2000)
     external_url = models.CharField(max_length=2000)
     stream_url = models.CharField(max_length=2000, blank=True, null=True)
